import { JsonMetadata } from '@metaplex-foundation/mpl-token-metadata';
import { Nullable, PublicKey } from '@metaplex-foundation/umi';
export declare type ReadApiAssetInterface = 'V1_NFT' | 'V1_PRINT' | 'LEGACY_NFT' | 'V2_NFT' | 'FungibleAsset' | 'Custom' | 'Identity' | 'Executable' | 'ProgrammableNFT';
export declare type ReadApiPropGroupKey = 'collection';
export declare type ReadApiPropSortBy = 'created' | 'updated' | 'recent_action';
export declare type ReadApiPropSortDirection = 'asc' | 'desc';
export declare type ReadApiParamAssetSortBy = {
    sortBy: ReadApiPropSortBy;
    sortDirection: ReadApiPropSortDirection;
};
export declare type ReadApiAssetContent = {
    json_uri: string;
    metadata: JsonMetadata;
};
export declare type ReadApiAssetCompression = {
    eligible: boolean;
    compressed: boolean;
    data_hash: PublicKey;
    creator_hash: PublicKey;
    asset_hash: PublicKey;
    tree: PublicKey;
    seq: number;
    leaf_id: number;
};
export declare type ReadApiAssetOwnership = {
    frozen: boolean;
    delegated: boolean;
    delegate: PublicKey | null;
    owner: PublicKey;
    ownership_model: 'single' | 'token';
};
export declare type ReadApiAssetSupply = {
    edition_nonce: number | null;
    print_current_supply: number;
    print_max_supply: number;
};
export declare type ReadApiAssetRoyalty = {
    royalty_model: 'creators';
    target: PublicKey | null;
    percent: number;
    primary_sale_happened: boolean;
    basis_points: number;
    locked: boolean;
};
export declare type ReadApiAssetCreator = {
    address: PublicKey;
    verified: boolean;
    share: number;
};
export declare type ReadApiAssetGrouping = {
    group_key: ReadApiPropGroupKey;
    group_value: string;
};
export declare type ReadApiAuthorityScope = 'full';
export declare type ReadApiAssetAuthority = {
    address: PublicKey;
    scopes: ReadApiAuthorityScope[];
};
export declare type GetAssetProofRpcResponse = {
    root: PublicKey;
    proof: PublicKey[];
    node_index: number;
    leaf: PublicKey;
    tree_id: PublicKey;
};
export declare type GetAssetsByGroupRpcInput = {
    groupKey: ReadApiPropGroupKey;
    groupValue: string;
    page?: Nullable<number>;
    limit?: Nullable<number>;
    before?: Nullable<string>;
    after?: Nullable<string>;
    sortBy?: Nullable<ReadApiParamAssetSortBy>;
};
export declare type GetAssetsByOwnerRpcInput = {
    /**
     * String of the owner's PublicKey address
     */
    owner: PublicKey;
    page?: Nullable<number>;
    limit?: Nullable<number>;
    before?: Nullable<string>;
    after?: Nullable<string>;
    sortBy?: Nullable<ReadApiParamAssetSortBy>;
};
export declare type ReadApiAsset = {
    /**
     * The asset Id
     */
    id: PublicKey;
    interface: ReadApiAssetInterface;
    ownership: ReadApiAssetOwnership;
    mutable: boolean;
    authorities: Array<ReadApiAssetAuthority>;
    content: ReadApiAssetContent;
    royalty: ReadApiAssetRoyalty;
    supply: ReadApiAssetSupply;
    creators: Array<ReadApiAssetCreator>;
    grouping: Array<ReadApiAssetGrouping>;
    compression: ReadApiAssetCompression;
};
export declare type ReadApiAssetList = {
    total: number;
    limit: number;
    /**
     * listing of individual assets, and their associated metadata
     */
    items: Array<ReadApiAsset>;
    /**
     * `page` is only provided when using page based pagination, as apposed
     * to asset id before/after based pagination
     */
    page: Nullable<number>;
    /**
     * asset Id searching before
     */
    before: Nullable<string>;
    /**
     * asset Id searching after
     */
    after: Nullable<string>;
    /**
     * listing of errors provided by the ReadApi RPC
     */
    errors: Nullable<ReadApiRpcResponseError[]>;
};
export declare type ReadApiRpcResponseError = {
    error: string;
    id: string;
};
